package guru.kake.ronove

import javafx.scene.control.TextField
import javafx.scene.text.FontSmoothingType
import kotlinx.html.*
import kotlinx.html.stream.createHTML
import netscape.javascript.JSObject
import tornadofx.*

/**
 * Tab class to display text using HTML formatting
 */
class ReaderTab : View("Reader") {
    private val cbobject: WebViewCallback = WebViewCallback()
    override val root = vbox {
        webview {
            style {
                fontSmoothingType = FontSmoothingType.GRAY
            }
            engine.loadContent(createHTML().html {
                head {
                    style {
                        unsafe { raw("body { font-size: 48px; }") }
                    }
                }
                body {
                    onLoad = "alert()"
                    p {
                        ruby { +"私"; rt { +"わたし" }}
                        +"の"
                        ruby { +"猫"; rt { +"ねこ" }}
                        +"わかわいいです"
                        ruby("a") {+"b"}
                        a("#") {
                            onClick = "cb.test('foo');"
                            +"linkki"
                        }
                    }

                }
            })

            engine.setOnAlert {
                (engine.executeScript("window") as JSObject).setMember("cb", cbobject)
            }
        }
    }
}

/**
 * Class for receiving events from JS in [ReaderTab]
 */
@Suppress("unused") // IDEA doesn't detect uses of these functions since they are called from JS in the WebView
class WebViewCallback {
    fun test(message: String) {
        println(message)
    }
}

/**
 * Tab class for displaying dictionaries
 */
class DictionaryTab : View("Dictionary") {
    override val root = vbox {
        hbox {
            textfield {  }
            textfield {  }
            textfield {  }
        }
        hbox {
            textfield {  }
            textfield {  }
            textfield {  }
        }
        hbox {
            textfield {  }
            textfield {  }
            textfield {  }
        }
    }
}

/**
 * Tab class for displaying original material in image form
 */
class ImageTab : View("Image") {
    override val root = vbox {
        imageview("/yopage.jpg") {
            fitWidth = 300.0
            isPreserveRatio = true
            isSmooth = true
        }
    }
}

/**
 * Tab class for a separate window letting the user run arbitrary strings through machine translation
 */
class TranslatorTab : View("Machine translation") {
    private var fromField: TextField by singleAssign()
    private var toField: TextField by singleAssign()

    //TODO allow switching languages on the fly
    override val root = vbox {
        vbox {
            label("Japanese")
            fromField = textfield()
            button("To English") {
                action {
                    TranslationBackend.destinationLanguage = "en-US"
                    TranslationBackend.sourceLanguage = "ja"
                    toField.text = TranslationBackend(fromField.text)
                }
            }
        }
        vbox {
            label("English")
            toField = textfield()
            button("To Japanese") {
                action {
                    TranslationBackend.destinationLanguage = "ja"
                    TranslationBackend.sourceLanguage = "en"
                    fromField.text = TranslationBackend(toField.text)
                }
            }
        }
    }

}