package guru.kake.ronove

import javafx.collections.FXCollections
import javafx.scene.image.Image
import javafx.stage.Modality
import javafx.stage.StageStyle
import tornadofx.*
import kotlin.system.exitProcess

/**
 * The main window of the program
 */
class MainView : View("Ronove") {
    override val root = borderpane {

        //Main menu
        top = menubar {
            menu("File") {
                item("New project...") {
                    action {
                    }
                }
                item("New empty project")
                separator()
                item("Open...").action {
                    chooseDirectory("Choose folder")
                }
                menu("Open recent") {
                    item("Recent 1")
                    item("Recent 2")
                    item("Recent 3")
                    item("Recent 4")
                    item("Recent 5")
                }
                separator()
                item("Save") {
                    action { TODO("Save") }
                }
                item("Save as...")
                item("Export...")
                separator()
                item("Exit").action {
                    //TODO: Confirm unsaved changes
                    exitProcess(0)
                }
            }
            menu("Edit") {
                item("Add page")
                item("Remove page")
                separator()
                item("Add line")
                item("Remove line")
                separator()
                item("Project settings...")
            }
            menu("Machine translation") {
                item("Translate line")
                item("Translate page")
                item("Translate all pages")
                separator()
                item("Machine translation settings...") {
                    action {
                        TranslationSettings().openModal()
                    }
                }
            }
            menu("Dictionary") {
                item("Project dictionary...")
                item("User dictionary...")
            }
            menu("Help") {
                item("Help")
                item("About")
            }
        }

        //Table view for editing data
        center<TranslationPageView>()

        //Status bar
        bottom = hbox {
            label("MTL: Deepl | ")
            label("API quota ")
            progressbar(TranslationBackend.quotaProperty)
            label(" 48 / 500,000 | ")
            val providers = FXCollections.observableArrayList("DeepL","Google Translate")
            combobox(values = providers)
        }

        //Drawer for tabbed tools
        right = drawer(multiselect = true) {
            maxWidth = 100.0
            item<ImageTab> {
                maxWidth = 100.0
            }
            item<ReaderTab>()
            item<DictionaryTab>()
            item<TranslatorTab>()
        }
    }

    init {
        primaryStage.icons.add(Image("/ronove128.png"))
        //openInternalWindow<SplashScreen>(params = mapOf(SplashScreen::project to (app as Ronove).project))
        SplashScreen((app as Ronove).project).openModal(stageStyle = StageStyle.UTILITY, block = true,
            modality = Modality.APPLICATION_MODAL, owner = primaryStage)
    }
}

